/*
* file CcElement.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcElement
*
* (C) Copyright IBM Corporation 2004, 2011.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/

package com.ibm.rational.wvcm.stp.cc;

import static com.ibm.rational.wvcm.stpex.StpExBase.PROPERTY_NAMESPACE;

import javax.wvcm.PropertyNameList.PropertyName;
import javax.wvcm.WvcmException;

/**
 * A proxy for a ClearCase element.
 * <p>
 * Items under Rational ClearCase source control (version control) are 
 * generally referred to as elements. An element can be a design model, 
 * C++ source file, Visual Studio project, or a DLL. Elements are typically 
 * the objects on which you do work. About versions, elements, and VOBs: 
 * each time you revise and check in a file or directory from a view, a new 
 * version of that element is created. Files and directories under Rational 
 * ClearCase control (and all of their constituent versions) are called 
 * elements and are stored in VOBs.
 * </p>
 * <p>
 * For more information about elements, see the ClearCase "Guide to Developing Software"
 * manual, and the cleartool man page "mkelem".
 * </p>
 */
public interface CcElement
    extends javax.wvcm.VersionHistory, CcVobResource
{
	/**
     * <p>
     * The view-relative path for this element.
     * </p>
     * <p>
     * NOTE: This property is only available if it is retrieved
     * using a method with a view context, such as
     * Resource.doReadProperties(CcView, PropertyRequest).
     * ClearCase needs a view context to resolve element paths.
     * </p>
     */
    PropertyName<String> VIEW_RELATIVE_PATH =
        new PropertyName<String>(PROPERTY_NAMESPACE, "element-view-relative-path");
    
    /**
     * Get the value of this element's {@link #VIEW_RELATIVE_PATH} property.
     * 
     * @return view-relative path for the element
     * @throws WvcmException
     *     if property was not requested, or if the view context
     *     was not provided
     */
    String getViewRelativePath() throws WvcmException;

    /** Get this element's element type. */
    PropertyName<CcElementType> ELEMENT_TYPE =
        new PropertyName<CcElementType>(PROPERTY_NAMESPACE,
                                                      "element-element-type");

    /**
     * Get the value of this element's {@link #ELEMENT_TYPE} property.
     * 
     * @return element type for the element
     * @throws WvcmException
     *     if property was not requested
     */
    CcElementType getElementType() throws WvcmException;

    
}
